@@ -12,8 +12,8 @@ class TemperatureSensor(EchonetInstance):
     }
 
     def __init__(self, host, api_connector = None, instance = 0x1):
-        self.eojgc = 0x00
-        self.eojcc = 0x11
+        self._eojgc = 0x00
+        self._eojcc = 0x11
         EchonetInstance.__init__(self, host, self._eojgc, self._eojcc, instance, api_connector)
 
     def getMeasuredTemperature(self):
