@@ -1,4 +1,5 @@
 from datetime import datetime, timezone
+from pychonet.lib.const import MANUFACTURERS
 
 #------------ EPC GENERIC FUNCTIONS -------
 def _int(edt):
@@ -35,27 +36,42 @@ def _0083(edt):
         return ops_value
     return None
 
+def _008A(edt): #manufacturer
+    id = int.from_bytes(edt, 'big')
+    if id in MANUFACTURERS.keys():
+        return MANUFACTURERS[id]
+    return id
+
+def _009A(edt): #cumulative runtime
+    if len(edt) > 1:
+        value = int.from_bytes(edt[1:], 'big')
+        time_period_multiplier = 0
+        if edt[0] == 0x41:
+            time_period_multiplier = 1 #measurement is in seconds
+        elif edt[0] == 0x42:
+            time_period_multiplier = 60 #measurement is in minutes
+        elif edt[0] == 0x43:
+            time_period_multiplier = 3600 #measurement is in hours
+        elif edt[0] == 0x44:
+            time_period_multiplier = 3600*24 #measurement is in days
+        return value * time_period_multiplier
+    return None
+
 EPC_SUPER_FUNCTIONS = {
     0x80: _0080,
-    0x8A: _int,
     0x83: _0083,
+    0x85: _int,
+    0x8A: _008A,
+    0x9A: _009A,
     0x9E: _009X,
     0x9F: _009X
 }
 
 
 # ------- EPC FUNCTIONS -------------------------------------------------
+# TODO - Move these to their classes
 # -----------------------------------------------------------------------
 
-def _0260EO(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-       0x41: 'open',
-       0x42: 'close',
-       0x43: 'stop'
-    }
-    return values.get(op_mode, "invalid_setting")
-
 # ----- Electric Lock Class -------
 def _026FEX(edt):
     op_mode = int.from_bytes(edt, 'big')
@@ -148,74 +164,3 @@ def _0288EA(edt):
     culmative = int.from_bytes(edt[7:], 'big')
     time = datetime(year, month, day, hour,minute,second)
     return {'time': datetime(year, month, day, hour,minute,second).isoformat(), 'culmative_value': culmative}
-
-# ----- General lighting class -------
-def _0290B1(edt):
-    op_mode = int.from_bytes(edt, 'big')
-    values = {
-       0x40: 'other',
-       0x41: 'incandescent_lamp_color',
-       0x42: 'white',
-       0x43: 'daylight_white',
-       0x43: 'daylight_color',
-    }
-    return values.get(op_mode, "invalid_setting")
-
-# EPC_FUNCTIONS = {
-#     0x00: {
-#         0x11:{
-#             0xE0: _0011E0,
-#             0XE1: _int
-#         }
-#     },
-#     0x01: {
-#         0x30:{
-#         	0xA0: _0130A0,
-#             0xA1: _0130A1,
-#             0xA3: _0130A3,
-#             0xA4: _0130A4,
-#             0xA5: _0130A5,
-#             0xAA: _0130AA,
-#             0xB0: _0130B0,
-#             0xB3: _int,
-#             0xBB: _int,
-#             0xBE: _int
-#         }
-#     },
-#     0x02: {
-#         0x60: {
-#             0xE0: _0260EO
-#         },
-#         0x6F: {
-#             0xE0: _026FEX,
-#             0xE1: _026FEX,
-#             0xE2: _026FEX,
-#             0xE3: _026FE3,
-#             0xE4: _026FE4,
-#             0xE5: _026FE5,
-#             0xE6: _026FE6,
-#             0xE7: _026FE7
-#         },
-#         0x79: {
-#             0xE0: _int,
-#             0xE1: _int
-#         },
-#         0x7d: {
-#             0xE4: _int,
-#             0xCF: _int
-#         },
-#         0x88: {
-#             0xd7: _int, #number of effective digits in culmative amout of energy
-#             0xe0: _int, #measured culmative amount of electricity
-#             0xe1: _0288E1, #multiplying factor
-#             # 0xe2:
-#             0xe5: _int,
-#             0xe7: _0288E7, #measured instantaneous electric energy
-#             0xe8: _0288E8, #measured instantanenous currents
-#             0xea: _0288EA
-#         },
-#         0x90: {
-#             0xB1: _0290B1
-#         }
-#     }
-# }
